summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgamelcd.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgamelcd.h')
-rw-r--r--libkdegames/kgamelcd.h25
1 files changed, 14 insertions, 11 deletions
diff --git a/libkdegames/kgamelcd.h b/libkdegames/kgamelcd.h
index 214af1f5..543cfef5 100644
--- a/libkdegames/kgamelcd.h
+++ b/libkdegames/kgamelcd.h
@@ -39,11 +39,12 @@ class TQTimer;
*
* @since 3.2
*/
-class KDE_EXPORT KGameLCD : public QLCDNumber
+class KDE_EXPORT KGameLCD : public TQLCDNumber
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameLCD(uint nbDigits, TQWidget *parent = 0, const char *name = 0);
+ KGameLCD(uint nbDigits, TQWidget *tqparent = 0, const char *name = 0);
~KGameLCD();
@@ -86,7 +87,7 @@ public:
public slots:
/**
- * Highlight the LCD with the QColorGourp::HighlightedText color
+ * Highlight the LCD with the TQColorGourp::HighlightedText color
* for a small time (setHighlightTime).
*/
void highlight();
@@ -126,8 +127,9 @@ private:
class KDE_EXPORT KGameLCDClock : public KGameLCD
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameLCDClock(TQWidget *parent = 0, const char *name = 0);
+ KGameLCDClock(TQWidget *tqparent = 0, const char *name = 0);
~KGameLCDClock();
@@ -182,37 +184,38 @@ private:
//-----------------------------------------------------------------------------
/**
- * This widget holds a list of @ref TQLCDNumber arranged in a vertical layout.
+ * This widget holds a list of @ref TQLCDNumber arranged in a vertical tqlayout.
* It also shows a label at the top of the list.
*
* @since 3.2
*/
-class KDE_EXPORT KGameLCDList : public QWidget
+class KDE_EXPORT KGameLCDList : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* @param title is the content of the top label.
* @param parent passed to the TQWidget constructor
* @param name passed to the TQWidget constructor
*/
KGameLCDList(const TQString &title,
- TQWidget *parent = 0, const char *name = 0);
- KGameLCDList(TQWidget *parent = 0, const char *name = 0);
+ TQWidget *tqparent = 0, const char *name = 0);
+ KGameLCDList(TQWidget *tqparent = 0, const char *name = 0);
~KGameLCDList();
/**
* Append a TQLCDNumber at the bottom of the list.
* The TQLCDNumber should have the KGameLCDList as parent.
*/
void append(TQLCDNumber *lcd);
/**
* Append a TQLCDNumber at the bottom of the list.
* The TQLCDNumber should have the KGameLCDList as parent.
*/
void append(const TQString &leading, TQLCDNumber *lcd);
@@ -182,37 +184,38 @@ private:
*
* @param title is the content of the top label.
- * @param parent passed to the TQWidget constructor
+ * @param tqparent passed to the TQWidget constructor
* @param name passed to the TQWidget constructor
*/
@@ -182,37 +184,38 @@ private:
/**
* Append a TQLCDNumber at the bottom of the list.
- * The TQLCDNumber should have the KGameLCDList as parent.
+ * The TQLCDNumber should have the KGameLCDList as tqparent.
*/
void append(TQLCDNumber *lcd);
@@ -182,37 +184,38 @@ private:
/**
* Append a TQLCDNumber at the bottom of the list.
- * The TQLCDNumber should have the KGameLCDList as parent.
+ * The TQLCDNumber should have the KGameLCDList as tqparent.
*/
void append(const TQString &leading, TQLCDNumber *lcd);